require 'test_helper'

describe Forward::API::Tunnel do

  before :each do
    Forward::Config.accounts = { foo: 'abc123' }
    Forward::Config.default_account = :foo
  end

  it "creates a tunnel and returns the attributes" do
    tunnel_options = { port: '3000', host: 'localhost' }
    params         = {
      hostport: tunnel_options[:port],
      vhost: tunnel_options[:host],
      subdomain: nil, cname: nil,
      username: nil, password: nil, no_auth: nil,
      client: Forward.client_string,
    }
    body = { tunnel: { _id: '1', subdomain: 'foo', port: 56789 }}

    stub_request(:post, 'localhost/api/v3/tunnels/').
      with(body: params.to_json).
      to_return(status: 200, body: body.to_json)

    EM.run_block {
      Forward::API::Tunnel.create(tunnel_options) do |tunnel|
        tunnel[:id].must_equal body[:id]
        tunnel[:subdomain].must_equal body[:subdomain]
        tunnel[:port].must_equal body[:port]
      end
    }
  end

  it "exits with message on 422" do
    tunnel_options = { port: '3000', host: 'localhost' }

    stub_request(:post, 'localhost/api/v3/tunnels/').
      to_return(status: 422)

    out, err = capture_io do
      begin
        EM.run_block {
          Forward::API::Tunnel.create(tunnel_options) { }
        }
      rescue SystemExit; end
    end
    out.must_match /unable to allocate tunnel/i
  end

  it "exits with message and displays account errors" do
     tunnel_options = { port: '3000', host: 'localhost' }
     body = {
       type: 'account_error',
       errors: { account: ['Trial has expired'] }
     }

     stub_request(:post, 'localhost/api/v3/tunnels/').
       to_return(status: 422, body: body.to_json)

     out, err = capture_io do
       begin
         EM.run_block {
           Forward::API::Tunnel.create(tunnel_options) { }
         }
       rescue SystemExit; end
     end
     out.must_match /trial has expired/i
   end

   it "exits with message on bad tunnel data" do
      tunnel_options = { port: '3000', host: 'localhost' }
      body = {
        type: 'invalid_request_error'
      }

      stub_request(:post, 'localhost/api/v3/tunnels/').
        to_return(status: 422, body: body.to_json)

      out, err = capture_io do
        begin
          EM.run_block {
            Forward::API::Tunnel.create(tunnel_options) { }
          }
        rescue SystemExit; end
      end
      out.must_match /invalid tunnel parameters/i
    end

end
