require 'test_helper'

describe Forward::API::User do

  it "retrieves the users api token and returns it" do
    params = { email: 'guy@example.com', password: 'secret' }
    body   = { subdomain: 'fooco', token: '123abc' }

    stub_request(:post, 'localhost/api/v3/user/token').
      with(body: params.to_json).
      to_return(status: 200, body: body.to_json)

    EM.run_block {
      Forward::API::User.authenticate(params[:email], params[:password]) do |subdomain, token|
        token.must_equal '123abc'
      end
    }
  end

  it "exits with message if authentication fails" do
    params = { email: 'guy@example.com', password: 'secret' }

    stub_request(:post, 'localhost/api/v3/user/token').
      with(body: params.to_json).
      to_return(status: 401)

    out, err = capture_io do
      begin
        EM.run_block {
          Forward::API::User.authenticate(params[:email], params[:password]) {}
        }
      rescue SystemExit; end
    end
    out.must_match /Unable to authenticate/i
  end

  it "exits with message if response has errors" do
    params = { email: 'guy@example.com', password: 'secret' }

    stub_request(:post, 'localhost/api/v3/user/token').
      with(body: params.to_json).
      to_return(status: 422)

    out, err = capture_io do
      begin
        EM.run_block {
          Forward::API::User.authenticate(params[:email], params[:password]) {}
        }
      rescue SystemExit; end
    end
    out.must_match /Unable to authenticate/i
  end

end
