require 'test_helper'

describe Forward do

  it 'should know what the host OS is' do
    hosts = {
      'mswin'  => :windows,
      'mingw'  => :windows,
      'cygwin' => :windows,
      'darwin' => :osx,
      'linux'  => :unix,
      'bsd'    => :unix,
      'foo'    => :unknown,
    }

    hosts.each do |name, kind|
      RbConfig::CONFIG['host_os'] = name
      Forward.instance_variable_set("@os", nil)
      Forward.os.must_equal kind
    end
  end

  it 'should know when the host OS is windows' do
    RbConfig::CONFIG['host_os'] = 'mswin'
    Forward.instance_variable_set("@os", nil)
    Forward.must_be :windows?
  end

  it 'should set the log level to debug' do
    Forward.debug!
    Forward.logger.level.must_equal Logger::DEBUG
  end

  it 'should instantiate a logger' do
    Forward.logger.must_be_instance_of ::Logger
  end

  it 'should produce a client string identfier' do
    suppress_warnings do
      RbConfig::CONFIG['host_os'] = 'darwin13.0.0'
      RUBY_ENGINE                 = 'ruby'
      RUBY_VERSION                = '2.0.0'

      Forward.client_string.must_equal "(ruby-2.0.0)(darwin13.0.0)(v#{Forward::VERSION})"
    end
  end
end
