require 'test_helper'

describe Forward::Tunnel do
  before :each do
    @attributes = {
      id:       '1234',
      cname:    'foo.bar.com',
      vhost:    '127.0.0.1',
      hostport: '3000',
      tunneler: 'test.forwardhq.com',
      timeout:  0,
      url: 'test.fwd.wf'
    }
  end

  it "creates a tunnel instance" do
    tunnel = Forward::Tunnel.new(@attributes)

    tunnel.id.must_equal @attributes[:id]
    tunnel.cname.must_equal @attributes[:cname]
    tunnel.host.must_equal @attributes[:vhost]
    tunnel.port.must_equal @attributes[:hostport]
    tunnel.tunneler.must_equal @attributes[:tunneler]
    tunnel.timeout.must_equal @attributes[:timeout]

    tunnel.requests.must_be :empty?
    tunnel.wont_be :open?
    tunnel.socket.wont_be_nil
  end

  it "knows if the tunnel is forwarding a directory/static" do
    attributes = @attributes.dup
    attributes[:static_path] = './'

    tunnel = Forward::Tunnel.new(attributes)
    tunnel.must_be :static?
  end

  it "knows if the tunnel is open" do
    tunnel = Forward::Tunnel.new(@attributes)

    tunnel.wont_be :open?
    tunnel.instance_variable_set('@open', true)
    tunnel.must_be :open?
  end

  it "displays an appopriate message when forwarding" do
    attributes2 = @attributes.dup
    attributes2[:static_path] = './'

    tunnel  = Forward::Tunnel.new(@attributes)
    tunnel2 = Forward::Tunnel.new(attributes2)

    capture_io { tunnel.send(:display_ready_message) }.first.wont_match /directory/i
    capture_io { tunnel2.send(:display_ready_message) }.first.must_match /directory/i
  end
end
